@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/output.lisp,v 1.10 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/output.lisp,v 1.14 2008/05/24 03:06:22 edi Exp $
 
-;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2006-2009, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -29,7 +29,7 @@
 
 (in-package :chunga)
 
-(defmethod chunked-stream-output-chunking-p (object)
+(defmethod chunked-stream-output-chunking-p ((object t))
   "The default method for all objects which are not of type
 CHUNKED-OUTPUT-STREAM."
   nil)
@@ -39,17 +39,14 @@ CHUNKED-OUTPUT-STREAM."
                              (end (length sequence)))
   "Writes the contents of SEQUENCE from START to END to the
 underlying stream of STREAM as one chunk."
-  (let ((output-stream (chunked-stream-output-stream stream)))
+  (let ((output-stream (chunked-stream-stream stream)))
     ;; chunk size
-    (format output-stream "~X" (- end start))
-    ;; CRLF
-    (write-string #.(format nil "~C~C" #\Return #\Linefeed) output-stream)
+    (loop for char across (format nil "~X" (- end start))
+          do (write-byte (char-code char) output-stream))
+    (write-sequence +crlf+ output-stream)
     ;; data
-    #+:clisp (setf (flexi-stream-element-type output-stream) 'octet)
     (write-sequence sequence output-stream :start start :end end)
-    #+:clisp (setf (flexi-stream-element-type output-stream) 'character)
-    ;; CRLF
-    (write-string #.(format nil "~C~C" #\Return #\Linefeed) output-stream)))
+    (write-sequence +crlf+ output-stream)))
 
 (defmethod flush-buffer ((stream chunked-output-stream))
   "Uses WRITE-CHUNK to empty the output buffer unless it is
@@ -63,22 +60,19 @@ already empty."
 (defmethod (setf chunked-stream-output-chunking-p) (new-value (stream chunked-output-stream))
   "Switches output chunking for STREAM on or off."
   (unless (eq (not new-value) (not (chunked-stream-output-chunking-p stream)))
-    (with-slots (output-stream output-index)
+    (with-slots (real-stream output-index)
         stream
       (cond (new-value
              ;; get rid of "old" data
-             (force-output output-stream)
-             (setq ;; wrap with flexi stream for character output
-                   output-stream (make-flexi-stream output-stream :external-format +latin-1+)
-                   ;; initialize output buffer as being empty
-                   output-index 0))
+             (force-output real-stream)
+             ;; initialize output buffer as being empty
+             (setq output-index 0))
             (t (flush-buffer stream)
                ;; last chunk to signal end of chunking
-               (write-string #.(format nil "0~C~C~C~C"
-                                       #\Return #\Linefeed #\Return #\Linefeed)
-                             output-stream)
-               ;; switch back to original inner stream
-               (setq output-stream (flexi-stream-stream output-stream))))))
+               (write-byte #.(char-code #\0) real-stream)
+               (write-sequence +crlf+ real-stream)
+               (write-sequence +crlf+ real-stream)
+               (force-output real-stream)))))
   (setf (slot-value stream 'output-chunking-p) new-value))
 
 (defmethod stream-clear-output ((stream chunked-output-stream))
@@ -86,21 +80,21 @@ already empty."
 the underlying stream."
   (when (chunked-stream-output-chunking-p stream)
     (setf (slot-value stream 'output-index) 0))
-  (clear-output (chunked-stream-output-stream stream)))
+  (clear-output (chunked-stream-stream stream)))
 
 (defmethod stream-finish-output ((stream chunked-output-stream))
   "Flush the output buffer if output chunking is on, then operate
 on the underlying stream."
   (when (chunked-stream-output-chunking-p stream)
     (flush-buffer stream))
-  (finish-output (chunked-stream-output-stream stream)))
+  (finish-output (chunked-stream-stream stream)))
 
 (defmethod stream-force-output ((stream chunked-output-stream))
   "Flush the output buffer if output chunking is on, then operate
 on the underlying stream."
   (when (chunked-stream-output-chunking-p stream)
     (flush-buffer stream))
-  (force-output (chunked-stream-output-stream stream)))
+  (force-output (chunked-stream-stream stream)))
 
 (defmethod stream-write-byte ((stream chunked-output-stream) byte)
   "Writes one byte by simply adding it to the end of the output
@@ -108,7 +102,7 @@ buffer \(if output chunking is enabled).  The buffer is flushed
 if necessary."
   (unless (chunked-stream-output-chunking-p stream)
     (return-from stream-write-byte
-      (write-byte byte (chunked-stream-output-stream stream))))
+      (write-byte byte (chunked-stream-stream stream))))
   (with-slots (output-index output-buffer)
       stream
     (when (>= output-index +output-buffer-size+)
@@ -123,7 +117,7 @@ small enough.  Large sequences are written directly using
 WRITE-CHUNK."
   (unless (chunked-stream-output-chunking-p stream)
     (return-from stream-write-sequence
-      (write-sequence sequence (chunked-stream-output-stream stream) :start start :end end)))
+      (write-sequence sequence (chunked-stream-stream stream) :start start :end end)))
   (with-slots (output-buffer output-index)
       stream
     (let ((length (- end start)))
