@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CHUNGA; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/chunga/streams.lisp,v 1.7 2007/01/01 23:39:36 edi Exp $
+;;; $Header: /usr/local/cvsrep/chunga/streams.lisp,v 1.10 2008/05/24 03:06:22 edi Exp $
 
-;;; Copyright (c) 2006-2007, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2006-2009, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -39,10 +39,7 @@ MAKE-CHUNKED-STREAM is of this type which is a subtype of
 STREAM."))
 
 (defclass chunked-input-stream (chunked-stream fundamental-binary-input-stream)
-  ((input-stream :accessor chunked-stream-input-stream
-                 :documentation "The underlying stream \(see
-REAL-STREAM) used for input, maybe wrapped with a flexi stream.")
-   (input-chunking-p :initform nil
+  ((input-chunking-p :initform nil
                      :reader chunked-stream-input-chunking-p
                      :documentation "Whether input chunking is currently enabled.")
    (input-buffer :initform nil
@@ -76,14 +73,11 @@ underlying stream is an input stream. This is a subtype of
 CHUNKED-STREAM."))
 
 (defclass chunked-output-stream (chunked-stream fundamental-binary-output-stream)
-  ((output-stream :accessor chunked-stream-output-stream
-                  :documentation "The underlying stream \(see
-REAL-STREAM) used for output, maybe wrapped with a flexi stream.")
-   (output-chunking-p :initform nil
+  ((output-chunking-p :initform nil
                       :reader chunked-stream-output-chunking-p
                       :documentation "Whether output chunking is
 currently enabled.")
-   (output-buffer :initform (make-array +output-buffer-size+ :element-type 'octet)
+   (output-buffer :initform (make-array +output-buffer-size+ :element-type '(unsigned-byte 8))
                   :accessor output-buffer
                   :documentation "A vector used to temporary
 store data which will output in one chunk.")
@@ -102,7 +96,7 @@ a CHUNKED-INPUT-STREAM as well as a CHUNKED-OUTPUT-STREAM."))
 (defmethod stream-element-type ((stream chunked-stream))
   "Chunked streams are always binary streams.  Wrap them with
 flexi streams if you need a character stream."
-  'octet)
+  '(unsigned-byte 8))
 
 (defmethod open-stream-p ((stream chunked-stream))
   "A chunked stream is open if its underlying stream is open."
@@ -116,52 +110,16 @@ flexi streams if you need a character stream."
            (close real-stream :abort abort))
           (t nil))))
 
-(define-condition input-chunking-unexpected-end-of-file (stream-error)
-  ()
-  (:documentation "A condition of this type is signaled if we
-reach an unexpected EOF on a chunked stream with input chunking
-enabled.  This is a subtype of STREAM-ERROR, so
-STREAM-ERROR-STREAM can be used to access the offending
-stream."))
-
-(define-condition input-chunking-body-corrupted (stream-error)
-  ((last-char :initarg :last-char
-              :documentation "The \(unexpected) character which was read.")
-   (expected-chars :initarg :expected-chars
-                   :documentation "The characters which were
-expected.  A list of characters or one single character."))
-  (:report (lambda (condition stream)
-             (with-slots (last-char expected-chars)
-                 condition
-               (format stream "Chunked stream ~S seems to be corrupted.
-Read character ~S, but expected ~:[a member of ~S~;~S~]."
-                       (stream-error-stream condition)
-                       last-char (atom expected-chars) expected-chars))))
-  (:documentation "A condition of this type is signaled if an
-unexpected character \(octet) is read while reading from a
-chunked stream with input chunking enabled. This is a subtype of
-STREAM-ERROR, so STREAM-ERROR-STREAM can be used to access the
-offending stream."))
-
-(defmethod initialize-instance :after ((stream chunked-input-stream) &rest initargs)
-  "Initializes the INPUT-STREAM slot."
-  (declare (ignore initargs))
-  (setf (chunked-stream-input-stream stream)
-        (chunked-stream-stream stream)))
-
-(defmethod initialize-instance :after ((stream chunked-output-stream) &rest initargs)
-  "Initializes the INPUT-STREAM slot."
-  (declare (ignore initargs))
-  (setf (chunked-stream-output-stream stream)
-        (chunked-stream-stream stream)))
-
 (defun make-chunked-stream (stream)
   "Creates and returns a chunked stream \(a stream of type
 CHUNKED-STREAM) which wraps STREAM.  STREAM must be an open
 binary stream."
   (unless (and (streamp stream)
                (open-stream-p stream))
-    (error "~S should have been an open stream." stream))
+    (error 'parameter-error
+           :stream stream
+           :format-control "~S should have been an open stream."
+           :format-arguments (list stream)))
   (make-instance ;; actual type depends on STREAM
                  (cond ((and (input-stream-p stream)
                              (output-stream-p stream))
